@@ -1,11 +1,12 @@
-use crate::schema::{ErrorResponse, Response, ResponseType, Result};
+use crate::schema::{ErrorResponse, FugleError, Response, ResponseType, Result};
 use std::time::Duration;
-use ureq::{Agent, AgentBuilder, Request};
+use ureq::{Agent, AgentBuilder, OrAnyStatus, Request};
 
-const INTRADAY_CHART: &str = "https://api.fugle.tw/realtime/v0.2/intraday/chart";
-const INTRADAY_QUOTE: &str = "https://api.fugle.tw/realtime/v0.2/intraday/quote";
-const INTRADAY_META: &str = "https://api.fugle.tw/realtime/v0.2/intraday/meta";
-const INTRADAY_DEALTS: &str = "https://api.fugle.tw/realtime/v0.2/intraday/dealts";
+const INTRADAY_CHART: &str = "https://api.fugle.tw/realtime/v0.3/intraday/chart";
+const INTRADAY_QUOTE: &str = "https://api.fugle.tw/realtime/v0.3/intraday/quote";
+const INTRADAY_META: &str = "https://api.fugle.tw/realtime/v0.3/intraday/meta";
+const INTRADAY_DEALTS: &str = "https://api.fugle.tw/realtime/v0.3/intraday/dealts";
+const INTRADAY_VOLUMES: &str = "https://api.fugle.tw/realtime/v0.3/intraday/volumes";
 
 /// Accumulates options towards building an Intraday instance.
 pub struct IntradayBuilder {
@@ -197,6 +198,33 @@ impl Intraday {
                 .query("symbolId", symbol_id),
         }
     }
+
+    /// [Endpoint](https://developer.fugle.tw/document/intraday/volumes)
+    ///
+    /// Fetching today's volume information.
+    ///
+    /// # Example:
+    ///
+    /// ```
+    /// # fn main() -> fugle::schema::Result<()> {
+    /// # use fugle::crawler::IntradayBuilder;
+    ///
+    /// let agent = IntradayBuilder::new().build();
+    /// agent.volumes("2884").call()?;
+    ///
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn volumes(&self, symbol_id: &str) -> GetQueryBuilder {
+        GetQueryBuilder {
+            resposne_type: ResponseType::Volumes,
+            request: self
+                .agent
+                .get(INTRADAY_VOLUMES)
+                .query("apiToken", &self.token)
+                .query("symbolId", symbol_id),
+        }
+    }
 }
 
 /// Associate options when doing the request.
@@ -294,17 +322,21 @@ impl GetQueryBuilder {
     /// # }
     /// ```
     pub fn call(self) -> Result<Response> {
-        let response = self.request.call()?;
-        if response.status() != 200 {
-            let err: ErrorResponse = response.into_json()?;
-            return Err(err.into());
-        }
-
-        match self.resposne_type {
-            ResponseType::Chart => Ok(Response::Chart(response.into_json()?)),
-            ResponseType::Meta => Ok(Response::Meta(response.into_json()?)),
-            ResponseType::Quote => Ok(Response::Quote(response.into_json()?)),
-            ResponseType::Dealts => Ok(Response::Dealts(response.into_json()?)),
+        match self.request.call().or_any_status() {
+            Ok(response) => {
+                if response.status() != 200 {
+                    let err: ErrorResponse = response.into_json()?;
+                    return Err(err.into());
+                }
+                match self.resposne_type {
+                    ResponseType::Chart => Ok(Response::Chart(response.into_json()?)),
+                    ResponseType::Meta => Ok(Response::Meta(response.into_json()?)),
+                    ResponseType::Quote => Ok(Response::Quote(response.into_json()?)),
+                    ResponseType::Dealts => Ok(Response::Dealts(response.into_json()?)),
+                    ResponseType::Volumes => Ok(Response::Volumes(response.into_json()?)),
+                }
+            }
+            Err(e) => Err(FugleError::Ureq(Box::new(e.into()))),
         }
     }
 }
